# ODBP

## Development
ODBP is being developed by [CMML](https://www.cmml.me.msstate.edu), and as such has a focus on Additive Manufacturing Thermal models (especially for Wire Arc Directed Energy Deposition) though it may work for other applications.

## Install with pip
```shell
pip install odbp["all"]
```

## Or for data processing with no plotting
```shell
pip install odbp
```

## See [GETTING STARTED](./GETTING_STARTED.md) for basic tutorial.
### April 2024: The above GETTING STARTED is out of date. It will be fixed soon!

## See [the example odbs repository](https://data.mendeley.com/datasets/g9m574ybt8/2) for the small .odb files used to benchmark ODBP
